@@ -36,6 +36,7 @@ from ..db.component_state_store import ComponentStateStore
 from ..db.engine_state import EngineState
 from ..db.prod_info import ProdInfo
 from ..db.startup_state import StartupState
+from ..db.sync_state import SyncState
 from ..gpio.gpio_handler import GpioHandler
 from ..pdi.amc2_req import Amc2Req, Direction
 from ..pdi.asc2_req import Asc2Req
@@ -272,7 +273,7 @@ class PyTrain:
                 flush=True,
             )
             sync_state = self._state_store.get_state(CommandScope.SYNC, 99)
-            if sync_state is not None:
+            if isinstance(sync_state, SyncState):
                 while not sync_state.is_synchronized:
                     cycle += 1
                     print(
@@ -1033,8 +1034,8 @@ class PyTrain:
             cycle = 0
             cursor = {0: "|", 1: "/", 2: "-", 3: "\\"}
             print(f"Loading roster from Lionel Base at {self._base_addr}... {cursor[cycle]}", end="\r")
-            if sync_state is not None:
-                while sync_state.is_synchronized is not True:
+            if isinstance(sync_state, SyncState):
+                while not sync_state.is_synchronized:
                     cycle += 1
                     print(f"Loading roster from Lionel Base at {self._base_addr}... {cursor[cycle % 4]}", end="\r")
                     sleep(0.10)
@@ -1147,7 +1148,7 @@ class PyTrain:
                         db = None
                         action = D4Action.QUERY
                     agr = D4Req(rec_no, pdi, action=action, start=start, data_length=length, data_bytes=db)
-        elif param_len >= 2 and param[0].lower().startswith("m"):
+        elif param_len >= 2 and param[0].lower().startswith("m"):  # Base Memory commands
             pdi = PdiCommand.BASE_MEMORY
             rec_no = int(param[1], 16) if "0x" in param[1] else int(param[1])
             start = (int(param[2], 16) if "0x" in param[2] else int(param[2])) if param_len > 2 else 0
