@@ -11,7 +11,7 @@ from __future__ import annotations
 
 import logging
 from abc import ABC, ABCMeta, abstractmethod
-from typing import Any, Callable, Generic, TypeVar
+from typing import Any, Callable, Generic, TypeVar, cast
 
 from ..pdi.base3_component import ConsistComponent, RouteComponent
 from ..pdi.pdi_req import PdiReq
@@ -94,13 +94,6 @@ class UpdatePkg:
 # written to the Base 3 so it can update other attached controllers and software.
 #
 BASE_MEMORY_ENGINE_READ_MAP = {
-    0xB8: CompDataHandler(
-        "_tmcc_id",
-        4,
-        lambda t: int(PdiReq.decode_text(t)),
-        lambda t: PdiReq.encode_text(str(t).zfill(4), 4),
-        True,
-    ),
     0x00: CompDataHandler("_prev_link"),
     0x01: CompDataHandler("_next_link"),
     0x02: CompDataHandler("_unk_2"),
@@ -152,6 +145,13 @@ BASE_MEMORY_ENGINE_READ_MAP = {
     0x69: CompDataHandler("_smoke"),
     0x6A: CompDataHandler("_speed_limit"),
     0x6B: CompDataHandler("_max_speed"),
+    0xB8: CompDataHandler(
+        "_tmcc_id",
+        4,
+        lambda t: int(PdiReq.decode_text(t)),
+        lambda t: PdiReq.encode_text(str(t).zfill(4), 4),
+        True,
+    ),
     0xBC: CompDataHandler(
         "_timestamp",
         4,
@@ -380,18 +380,20 @@ class CompData(ABC, Generic[R]):
                             state = ComponentStateStore.build().get_state(req.scope, req.address, False)
                             assert state is not None
                             with state.synchronizer:
+                                from src.pytrain.db.engine_state import EngineState
+
                                 if sub_field == "rpm":
                                     rpm = req.data
-                                    labor = state.labor
+                                    labor = cast(EngineState, state).labor
                                 else:
-                                    rpm = state.rpm
+                                    rpm = cast(EngineState, state).rpm
                                     labor = req.data
                             base_value = conv_tpl[1](rpm, labor)
                         elif sub_field == "smoke":
                             if cmd.is_tmcc1:
                                 base_value = conv_tpl[1](TMCC1_TO_BASE_SMOKE_MAP, req.data)
                             else:
-                                base_value = conv_tpl[1](TMCC1_TO_BASE_SMOKE_MAP, req.data)
+                                base_value = conv_tpl[1](TMCC2_TO_BASE_SMOKE_MAP, req.data)
                         else:
                             base_value = conv_tpl[1](req.data)
                     else:
@@ -638,14 +640,24 @@ class RouteData(CompData):
 
     def payload(self) -> str:
         sw = ""
+        ro = ""
         if self._components:
-            sw = "Switches: "
-            sep = ""
+            sw = ro = sep = ""
             for c in self._components:
-                state = "thru" if c.is_thru else "out"
-                sw += f"{sep}{c.tmcc_id:>2} [{state}]"
-                sep = ", "
-        return sw
+                if c.is_route:
+                    if not ro:
+                        ro = "Routes: "
+                        sep = ""
+                    ro += f"{sep}{c.tmcc_id:>2}"
+                    sep = ", "
+                elif c.is_switch:
+                    if not sw:
+                        sw = "Switches: "
+                        sep = ""
+                    state = "thru" if c.is_thru else "out"
+                    sw += f"{sep}{c.tmcc_id:>2} [{state}]"
+                    sep = ", "
+        return (" ".join([ro, sw])).strip()
 
 
 class CompDataMixin(Generic[C]):
