@@ -69,6 +69,7 @@ class ComponentState(ABC, CompDataMixin):
         self._address: int | None = None
         self._spare_1: int | None = None
         self._dependencies = DependencyCache.build()
+        self._config_requested = False
 
     def __repr__(self) -> str:
         if self.is_comp_data_record is True and not self.payload:
@@ -172,6 +173,11 @@ class ComponentState(ABC, CompDataMixin):
                     f"{self.friendly_scope} #{self._address} received update for "
                     f"{command.scope.name.title()} #{command.address}, ignoring"
                 )
+            # have we received the initial configuration from Base 3? If not, trigger request
+            # and requeue this update.
+            if not self.is_comp_data_record and isinstance(command, CommandReq):
+                self.request_config(command)
+
             if self.scope != command.scope:
                 scope = command.scope.name.title()
                 raise AttributeError(f"{self.friendly_scope} {self.address} received update for {scope}, ignoring")
@@ -205,6 +211,36 @@ class ComponentState(ABC, CompDataMixin):
         self._last_updated = time()
         self._last_command = command
 
+    def request_config(self, command: CommandReq):
+        from ..comm.command_listener import CommandDispatcher
+        from ..pdi.base_req import BaseReq
+        from .component_state_store import ComponentStateStore
+
+        requeue = True
+        if ComponentStateStore.is_state_synchronized():
+            if not self._config_requested:
+                # if we're synchronized, this component may be new; request initial config
+                self.initialize(self.scope, self.tmcc_id)
+                scope = command.scope.name.title()
+                log.debug(f"{scope} {command.address} not known, will request config and retry {command}...")
+                if 1 <= command.address < 99:
+                    BaseReq(command.address, PdiCommand.BASE_MEMORY, scope=command.scope).send()
+                elif 100 <= command.address <= 9999:
+                    raise NotImplementedError(f"Cannot request 4-digit engine configuration: {command}")
+                self._config_requested = True
+            else:
+                print(f"Ignoring {command} as component is not yet synchronized")
+                requeue = False
+        if requeue:
+            self.schedule_call(2.5, CommandDispatcher.get().offer, command)
+            raise RequestConfigurationException()
+
+    @staticmethod
+    def schedule_call(delay_seconds, func, *args, **kwargs):
+        """Schedules a function call after a specified delay."""
+        timer = threading.Timer(delay_seconds, func, args=args, kwargs=kwargs)
+        timer.start()
+
     @property
     def last_updated_ago(self) -> float:
         if self._last_updated is not None:
@@ -253,8 +289,9 @@ class ComponentState(ABC, CompDataMixin):
             return byte_str
 
     def _update_comp_data(self, comp_data: CompData):
-        self._comp_data = comp_data
-        self._comp_data_record = True
+        with self._cv:
+            self._comp_data = comp_data
+            self._comp_data_record = True
 
     def _harvest_effect(self, effects: Set[E]) -> E | tuple[E, int] | None:
         for effect in effects:
@@ -444,21 +481,15 @@ class RouteState(TmccState):
         if scope != CommandScope.ROUTE:
             raise ValueError(f"Invalid scope: {scope}")
         super().__init__(scope)
-        self._signature: dict[int, bool] = dict()
-        self._current_state: dict[int, bool | None] = dict()
+        self._routes: set[RouteState] = set()
+        self._signature: dict[str, bool] = dict()
+        self._current_state: dict[str, bool | None] = dict()
 
     def update(self, command: L | P) -> None:
         if command:
             if command.command == TMCC1HaltCommandEnum.HALT:
                 return
             with self.synchronizer:
-                if not self.is_comp_data_record:
-                    if isinstance(command, CommandReq):
-                        from ..comm.command_listener import CommandDispatcher
-
-                        log.info(f"Still awaiting for initial state, will retry {command}...")
-                        CommandDispatcher.get().offer(command)
-                        return
                 super().update(command)
                 if isinstance(command, CompDataMixin) and command.is_comp_data_record:
                     self._update_comp_data(command.comp_data)
@@ -471,12 +502,20 @@ class RouteState(TmccState):
                         store = ComponentStateStore.get()
                         for comp in comps:
                             self._signature.update(comp.as_signature)
-                            switch = store.get_state(CommandScope.SWITCH, comp.tmcc_id, True)
-                            if isinstance(switch, SwitchState):
-                                self._current_state.update(
-                                    {switch.address: switch.is_thru if switch.is_known else None}
-                                )
-                                switch.register_route(self)
+                            if comp.is_switch:
+                                switch = store.get_state(CommandScope.SWITCH, comp.tmcc_id, True)
+                                if isinstance(switch, SwitchState):
+                                    self._current_state.update(
+                                        {f"S{switch.address}": switch.is_thru if switch.is_known else None}
+                                    )
+                                    switch.register_route(self)
+                            elif comp.is_route:
+                                route = store.get_state(CommandScope.ROUTE, comp.tmcc_id, True)
+                                if isinstance(route, RouteState):
+                                    self._current_state.update(
+                                        {f"R{route.address}": route.is_active if route.is_known else None}
+                                    )
+                                    route.register_route(self)
                 elif isinstance(command, CommandReq):
                     pass
                 else:
@@ -499,12 +538,23 @@ class RouteState(TmccState):
         return self._signature == self._current_state
 
     @property
-    def as_signature(self) -> dict[int, bool]:
+    def as_signature(self) -> dict[str, bool]:
         return self._signature
 
+    def register_route(self, route: RouteState):
+        self._routes.add(route)
+
     def update_switch_state(self, switch: SwitchState) -> None:
         with self.synchronizer:
-            self._current_state.update({switch.address: switch.is_thru if switch.is_known else None})
+            self._current_state.update({f"S{switch.address}": switch.is_thru if switch.is_known else None})
+            for route in self._routes:
+                route.update_route_state(self)
+            self.changed.set()
+            self._cv.notify_all()
+
+    def update_route_state(self, route: RouteState) -> None:
+        with self.synchronizer:
+            self._current_state.update({f"R{route.address}": route.is_active if route.is_known else None})
             self.changed.set()
             self._cv.notify_all()
 
@@ -512,10 +562,17 @@ class RouteState(TmccState):
         d = super()._as_dict()
         d["active"] = self.is_active
         if self.components:
-            sw = [{"switch": c.tmcc_id, "position": "thru" if c.is_thru is True else "out"} for c in self.components]
+            sw = [
+                {"switch": c.tmcc_id, "position": "thru" if c.is_thru is True else "out"}
+                for c in self.components
+                if c.is_switch
+            ]
+            rts = [{"route": c.tmcc_id} for c in self.components if c.is_route]
         else:
             sw = list()
+            rts = list()
         d["switches"] = sw
+        d["routes"] = rts
         return d
 
 
@@ -615,3 +672,7 @@ class ComponentStateDict(ThreadSafeDefaultDict):
             value._address = key
             self[key] = value
             return self[key]
+
+
+class RequestConfigurationException(Exception):
+    pass
