@@ -1,11 +1,20 @@
+#
+#  PyTrain: a library for controlling Lionel Legacy engines, trains, switches, and accessories
+#
+#  Copyright (c) 2024-2025 Dave Swindell <pytraininfo.gmail.com>
+#
+#  SPDX-License-Identifier: LPGL
+#
+from __future__ import annotations
+
 import atexit
-import gc
 import logging
 from abc import ABC, ABCMeta, abstractmethod
-from threading import Condition, RLock, Thread
+from threading import Condition, Event, RLock, Thread, get_ident
+from tkinter import TclError
 from typing import Callable, Generic, TypeVar, cast
 
-from guizero import App, Box, PushButton, Text
+from guizero import App, Box, Combo, PushButton, Text
 
 from ..comm.command_listener import CommandDispatcher
 from ..db.accessory_state import AccessoryState
@@ -32,6 +41,7 @@ class StateBasedGui(Thread, Generic[S], ABC):
         label: str = None,
         width: int = None,
         height: int = None,
+        aggrigator: ComponentStateGui = None,
         enabled_bg: str = "green",
         disabled_bg: str = "black",
         enabled_text: str = "black",
@@ -39,6 +49,7 @@ class StateBasedGui(Thread, Generic[S], ABC):
     ) -> None:
         Thread.__init__(self, daemon=True, name=f"{title} GUI")
         self._cv = Condition(RLock())
+        self._ev = Event()
         if width is None or height is None:
             try:
                 from tkinter import Tk
@@ -54,6 +65,7 @@ class StateBasedGui(Thread, Generic[S], ABC):
             self.height = height
         self.title = title
         self.label = label
+        self._aggrigator = aggrigator
 
         self._enabled_bg = enabled_bg
         self._disabled_bg = disabled_bg
@@ -63,6 +75,7 @@ class StateBasedGui(Thread, Generic[S], ABC):
         self.right_arrow = find_file("right_arrow.jpg")
         self.app = self.by_name = self.by_number = self.box = self.btn_box = self.y_offset = None
         self.pd_button_height = self.pd_button_width = self.left_scroll_btn = self.right_scroll_btn = None
+        self.aggrigator_combo = None
         self._max_name_len = 0
         self._max_button_rows = self._max_button_cols = None
         self._first_button_col = 0
@@ -72,6 +85,7 @@ class StateBasedGui(Thread, Generic[S], ABC):
         # States
         self._states = dict[int, S]()
         self._state_buttons = dict[int, PushButton]()
+        self._state_watchers = dict[int, StateWatcher]()
 
         # listen for state changes
         self._dispatcher = CommandDispatcher.get()
@@ -85,18 +99,27 @@ class StateBasedGui(Thread, Generic[S], ABC):
             self._sync_watcher = StateWatcher(self._sync_state, self.on_sync)
 
         self._is_closed = False
-        atexit.register(self.close)
+
+        # Thread-aware shutdown signaling
+        self._tk_thread_id: int | None = None
+        self._shutdown_flag = Event()
+
+        # Important: don't call tkinter from atexit; only signal
+        atexit.register(lambda: self._shutdown_flag.set())
 
     def close(self) -> None:
-        with self._cv:
-            if not self._is_closed:
-                self._is_closed = True
-                self.app.after(10, self.app.destroy)
-                self.join()
+        # Only signal shutdown here; actual tkinter destroy happens on the GUI thread
+        if not self._is_closed:
+            self._is_closed = True
+            self._shutdown_flag.set()
 
     def reset(self) -> None:
         self.close()
 
+    @property
+    def destroy_complete(self) -> Event:
+        return self._ev
+
     # noinspection PyTypeChecker
     def on_sync(self) -> None:
         if self._sync_state.is_synchronized:
@@ -111,7 +134,8 @@ class StateBasedGui(Thread, Generic[S], ABC):
                 nl = len(acc.road_name)
                 self._max_name_len = nl if nl > self._max_name_len else self._max_name_len
                 self._states[acc.tmcc_id] = acc
-                StateWatcher(acc, self.on_state_change_action(acc))
+                self._state_watchers[acc.tmcc_id] = StateWatcher(acc, self.on_state_change_action(acc))
+
             # start GUI
             self.start()
 
@@ -132,20 +156,48 @@ class StateBasedGui(Thread, Generic[S], ABC):
         return upd
 
     def run(self) -> None:
+        self._ev.clear()
+        self._tk_thread_id = get_ident()
         GpioHandler.cache_handler(self)
         self.app = app = App(title=self.title, width=self.width, height=self.height)
         app.full_screen = True
         app.when_closed = self.close
 
+        # poll for shutdown requests from other threads; this runs on the GuiZero/Tk thread
+        def _poll_shutdown():
+            if self._shutdown_flag.is_set():
+                try:
+                    app.destroy()
+                except TclError:
+                    pass  # ignore, we're shutting down
+                return None
+            return None
+
+        app.repeat(500, _poll_shutdown)
+
         self.box = box = Box(app, layout="grid")
         app.bg = box.bg = "white"
 
-        # customize label
-        label = f"{self.label} {self.title}" if self.label else self.title
-
         _ = Text(box, text=" ", grid=[0, 0, 6, 1], size=6, height=1, bold=True)
         _ = Text(box, text="    ", grid=[1, 1], size=24)
-        _ = Text(box, text=label, grid=[2, 1, 2, 1], size=24, bold=True)
+        if self._aggrigator:
+            ag_box = Box(box, grid=[2, 1, 2, 1])
+            if self.label:
+                _ = Text(ag_box, text=self.label, align="left", size=24, bold=True, height="fill")
+            self.aggrigator_combo = Combo(
+                ag_box,
+                options=self._aggrigator.guis,
+                selected=self.title,
+                align="right",
+                command=self.on_combo_change,
+            )
+            self.aggrigator_combo.text_size = 24
+            self.aggrigator_combo.text_bold = True
+        else:
+            # customize label
+            label = f"{self.label} {self.title}" if self.label else self.title
+
+            _ = Text(box, text=label, grid=[2, 1, 2, 1], size=24, bold=True)
         _ = Text(box, text="    ", grid=[4, 1], size=24)
         self.by_number = PushButton(
             box,
@@ -201,10 +253,33 @@ class StateBasedGui(Thread, Generic[S], ABC):
         self.sort_by_number()
 
         # Display GUI and start event loop; call blocks
-        self._app_active = True
-        self.app.display()
-        self.app = None
-        gc.collect()
+        try:
+            app.display()
+        except TclError:
+            # If Tcl is already tearing down, ignore
+            pass
+        finally:
+            # Explicitly drop references to tkinter/guizero objects on the Tk thread
+            if self._aggrigator:
+                for sw in self._state_watchers.values():
+                    sw.shutdown()
+                self._state_watchers.clear()
+            self.aggrigator_combo = None
+            self.left_scroll_btn = None
+            self.right_scroll_btn = None
+            self.by_name = None
+            self.by_number = None
+            self.btn_box = None
+            self.box = None
+            self._state_buttons.clear()
+            self.app = None
+            self._ev.set()
+
+    def on_combo_change(self, option: str) -> None:
+        if option == self.title:
+            return  # Noop
+        else:
+            self._aggrigator.cycle_gui(option)
 
     # noinspection PyUnusedLocal
     def _reset_state_buttons(self) -> None:
@@ -311,8 +386,14 @@ class StateBasedGui(Thread, Generic[S], ABC):
 
 
 class PowerDistrictsGui(StateBasedGui):
-    def __init__(self, label: str = None, width: int = None, height: int = None) -> None:
-        StateBasedGui.__init__(self, "Power Districts", label, width, height)
+    def __init__(
+        self,
+        label: str = None,
+        width: int = None,
+        height: int = None,
+        aggrigator: ComponentStateGui = None,
+    ) -> None:
+        StateBasedGui.__init__(self, "Power Districts", label, width, height, aggrigator)
 
     def get_target_states(self) -> list[AccessoryState]:
         pds: list[AccessoryState] = []
@@ -335,8 +416,14 @@ class PowerDistrictsGui(StateBasedGui):
 
 
 class SwitchesGui(StateBasedGui):
-    def __init__(self, label: str = None, width: int = None, height: int = None) -> None:
-        StateBasedGui.__init__(self, "Switches", label, width, height, disabled_bg="red")
+    def __init__(
+        self,
+        label: str = None,
+        width: int = None,
+        height: int = None,
+        aggrigator: ComponentStateGui = None,
+    ) -> None:
+        StateBasedGui.__init__(self, "Switches", label, width, height, aggrigator, disabled_bg="red")
 
     def get_target_states(self) -> list[SwitchState]:
         pds: list[SwitchState] = []
@@ -359,8 +446,14 @@ class SwitchesGui(StateBasedGui):
 
 
 class RoutesGui(StateBasedGui):
-    def __init__(self, label: str = None, width: int = None, height: int = None) -> None:
-        StateBasedGui.__init__(self, "Routes", label, width, height, disabled_bg="red")
+    def __init__(
+        self,
+        label: str = None,
+        width: int = None,
+        height: int = None,
+        aggrigator: ComponentStateGui = None,
+    ) -> None:
+        StateBasedGui.__init__(self, "Routes", label, width, height, aggrigator, disabled_bg="red")
 
     def get_target_states(self) -> list[RouteState]:
         pds: list[RouteState] = []
@@ -383,8 +476,14 @@ class RoutesGui(StateBasedGui):
 
 
 class AccessoriesGui(StateBasedGui):
-    def __init__(self, label: str = None, width: int = None, height: int = None) -> None:
-        StateBasedGui.__init__(self, "Accessories", label, width, height)
+    def __init__(
+        self,
+        label: str = None,
+        width: int = None,
+        height: int = None,
+        aggrigator: ComponentStateGui = None,
+    ) -> None:
+        StateBasedGui.__init__(self, "Accessories", label, width, height, aggrigator)
 
     def get_target_states(self) -> list[AccessoryState]:
         pds: list[AccessoryState] = []
@@ -406,3 +505,74 @@ class AccessoriesGui(StateBasedGui):
                 CommandReq(TMCC1AuxCommandEnum.AUX2_OPT_ONE, pd.tmcc_id).send()
             else:
                 CommandReq(TMCC1AuxCommandEnum.AUX2_OPT_ONE, pd.tmcc_id).send()
+
+
+class ComponentStateGui(Thread):
+    def __init__(
+        self,
+        label: str = None,
+        initial: str = "Power Districts",
+        width: int = None,
+        height: int = None,
+    ) -> None:
+        super().__init__(daemon=True)
+        self._ev = Event()
+        self._guis = {
+            # "Accessories": AccessoriesGui,
+            "Power Districts": PowerDistrictsGui,
+            "Switches": SwitchesGui,
+            "Routes": RoutesGui,
+        }
+        # verify requested GUI exists:
+        if initial not in self._guis:
+            raise ValueError(f"Invalid initial GUI: {initial}")
+
+        self.label = label
+        if width is None or height is None:
+            try:
+                from tkinter import Tk
+
+                root = Tk()
+                self.width = root.winfo_screenwidth()
+                self.height = root.winfo_screenheight()
+                root.destroy()
+            except Exception as e:
+                log.exception("Error determining window size", exc_info=e)
+        else:
+            self.width = width
+            self.height = height
+        self._gui = None
+        self.requested_gui = initial
+
+        self.start()
+
+    def run(self) -> None:
+        # create the initially requested gui
+        self._gui = self._guis[self.requested_gui](self.label, self.width, self.height, aggrigator=self)
+
+        # wait for user to request a different GUI
+        while True:
+            # Wait for request to change GUI
+            self._ev.wait()
+            self._ev.clear()
+
+            # Close/destroy previous GUI
+            GpioHandler.release_handler(self._gui)
+
+            # wait for Gui to be destroyed
+            self._gui.destroy_complete.wait(10)
+            self._gui.join()
+            # clean up state
+            self._gui = None
+
+            # create and display new gui
+            self._gui = self._guis[self.requested_gui](self.label, self.width, self.height, aggrigator=self)
+
+    def cycle_gui(self, gui: str):
+        if gui in self._guis:
+            self.requested_gui = gui
+            self._ev.set()
+
+    @property
+    def guis(self) -> list[str]:
+        return list(self._guis.keys())
