@@ -7,9 +7,9 @@
 #
 import atexit
 import logging
-from threading import Condition, RLock, Thread
+from threading import Condition, Event, RLock, Thread
 from time import time
-from tkinter import RAISED
+from tkinter import RAISED, TclError
 
 from guizero import App, Box, PushButton, Text
 
@@ -97,13 +97,33 @@ class LaunchGui(Thread):
         self._is_countdown = False
         self._is_flashing = False
         self.started_up = False
+        self._monitored_state_watcher = None
+        self._state_changed_flag = Event()
+
+        # Thread-aware shutdown signaling
+        self._tk_thread_id: int | None = None
+        self._shutdown_flag = Event()
+        self._is_closed = False
+
         if self._sync_state and self._sync_state.is_synchronized is True:
             self._sync_watcher = None
             self.on_sync()
         else:
             self._sync_watcher = StateWatcher(self._sync_state, self.on_sync)
-        self._is_closed = False
-        atexit.register(self.close)
+
+    def close(self) -> None:
+        if not self._is_closed:
+            self._is_closed = True
+            if self._monitored_state_watcher:
+                self._monitored_state_watcher.shutdown()
+                self._monitored_state_watcher = None
+            self._shutdown_flag.set()
+
+    def reset(self):
+        self.close()
+
+        # Important: don't call tkinter from atexit; only signal
+        atexit.register(lambda: self._shutdown_flag.set())
 
     def scale(self, value: int, factor: float = None) -> int:
         orig_value = value
@@ -122,30 +142,16 @@ class LaunchGui(Thread):
             if self._monitored_state is None:
                 raise ValueError(f"No state found for tmcc_id: {self.tmcc_id}")
             # watch for external state changes
-            StateWatcher(self._monitored_state, self.sync_gui_state)
+            self._monitored_state_watcher = StateWatcher(self._monitored_state, self.sync_gui_state)
             # start GUI
             self.start()
             # listen for state updates
             self._dispatcher.subscribe(self, CommandScope.ENGINE, self.tmcc_id)
 
-    def close(self) -> None:
-        if not self._is_closed:
-            self._is_closed = True
-            self.app.after(10, self.app.destroy)
-            self.join()
-
-    def reset(self):
-        self.close()
-
     def sync_gui_state(self) -> None:
         if self._monitored_state:
-            # power on?
-            if self._monitored_state.is_started is True:
-                self.app.after(10, self.do_power_on)
-                self.app.after(20, self.sync_pad_lights)
-            else:
-                self.set_lights_on_icon()
-                self.app.after(10, self.do_power_off)
+            with self._cv:
+                self._state_changed_flag.set()
 
     def sync_pad_lights(self):
         if self._monitored_state.is_aux2 is True:
@@ -172,10 +178,19 @@ class LaunchGui(Thread):
         if cmd != self._last_cmd or (time() - self._last_cmd_at) >= 1.0:
             self._last_cmd_at = time()
             if cmd.command == TMCC1EngineCommandEnum.NUMERIC:
+                # Gantry Movement/Startup
                 if cmd.data in (3, 6):
                     # mark launch pad as on
                     self.app.after(10, self.do_power_on)
-                    self.app.after(20, self.sync_pad_lights)
+                    # startup preceded by Aux1
+                    if self._last_cmd and self._last_cmd.command != TMCC1EngineCommandEnum.AUX1_OPTION_ONE:
+                        self.app.after(20, self.lights_on_req.send)
+                        self.app.after(30, self.set_klaxon_on_icon)
+                        # gantry retract
+                        if cmd.data == 6:
+                            self.app.after(8000, self.set_klaxon_off_icon)
+                            self.app.after(8000, self.lights_off_req.send)
+                    # self.app.after(20, self.sync_pad_lights)
                 elif cmd.data == 5:  # power down
                     self.app.after(10, self.set_lights_on_icon)
                     self.app.after(20, self.do_power_off)
@@ -185,7 +200,7 @@ class LaunchGui(Thread):
                     else:
                         # reset causes engine to start up, check for that state change here
                         self.app.after(10, self.sync_gui_state)
-                    self.app.after(20, self.do_klaxon_off)
+                    self.app.after(20, self.set_klaxon_off_icon)
             elif self.is_active():
                 if cmd.command == TMCC1EngineCommandEnum.REAR_COUPLER:
                     self.app.after(1, self.do_launch_detected, [15])
@@ -210,6 +225,31 @@ class LaunchGui(Thread):
         self.app = app = App(title="Launch Pad", width=self.width, height=self.height)
         app.full_screen = True
         app.when_closed = self.close
+
+        # poll for shutdown requests from other threads; this runs on the GuiZero/Tk thread
+        def _poll_shutdown():
+            if self._shutdown_flag.is_set():
+                try:
+                    app.destroy()
+                except TclError:
+                    pass  # ignore, we're shutting down
+                return None
+
+            with self._cv:
+                if self._state_changed_flag.is_set():
+                    self._state_changed_flag.clear()
+                    # power on?
+                    if self._monitored_state.is_started is True:
+                        self.do_power_on()
+                        self.sync_pad_lights()
+                    else:
+                        self.do_power_off()
+                        self.set_lights_on_icon()
+                    return None
+            return None
+
+        app.repeat(250, _poll_shutdown)
+
         self.upper_box = upper_box = Box(app, layout="grid", border=False)
 
         s_128 = self.scale(128)
@@ -288,7 +328,7 @@ class LaunchGui(Thread):
         _ = Text(lights_box, text="Lights", grid=[0, 0], size=self.s_16, underline=True)
         self.lights_button = PushButton(
             lights_box,
-            image=self.on_button,
+            image=self.on_button if self._monitored_state.is_aux2 is False else self.off_button,
             grid=[0, 1],
             command=self.toggle_lights,
             height=self.s_72,
@@ -374,8 +414,20 @@ class LaunchGui(Thread):
         # sync GUI with current state
         self.sync_gui_state()
 
-        # display GUI and start event loop; call blocks
-        self.app.display()
+        # Display GUI and start event loop; call blocks
+        try:
+            app.display()
+        except TclError:
+            # If Tcl is already tearing down, ignore
+            pass
+        finally:
+            self.upper_box = self.lower_box = self.message = None
+            self.launch = self.abort = self.pad = self.count = self.label = None
+            self.gantry_box = self.siren_box = self.klaxon_box = self.lights_box = None
+            self.power_button = self.lights_button = self.siren_button = self.klaxon_button = None
+            self.gantry_rev = self.gantry_fwd = None
+            self.comms_box = self.tower_comms = self.engr_comms = None
+            self.app = None
 
     def siren_sounded(self) -> None:
         self.toggle_sound(self.siren_button)
@@ -497,7 +549,8 @@ class LaunchGui(Thread):
 
     def do_power_off(self):
         with self._cv:
-            self.lights_off_req.send(repeat=2)
+            if self._monitored_state and self._monitored_state.is_aux2 is True:
+                self.lights_off_req.send(repeat=2)
             self.cancel_flashing()
             if self._is_countdown:
                 self.count.cancel(self.update_counter)
@@ -510,6 +563,8 @@ class LaunchGui(Thread):
             self.siren_box.disable()
             self.klaxon_box.disable()
             self.gantry_box.disable()
+            self.set_klaxon_off_icon()
+            self.set_lights_on_icon()
             if self.comms_box:
                 self.comms_box.disable()
 
@@ -545,10 +600,14 @@ class LaunchGui(Thread):
         else:
             self.lights_on_req.send(repeat=2)
 
-    def do_klaxon_off(self):
+    def set_klaxon_off_icon(self):
         self.klaxon_button.image = self.siren_off
         self.klaxon_button.height = self.klaxon_button.width = self.s_72
 
+    def set_klaxon_on_icon(self):
+        self.klaxon_button.image = self.siren_on
+        self.klaxon_button.height = self.klaxon_button.width = self.s_72
+
     def toggle_sound(self, button: PushButton):
         if button.enabled is True:
             self.lower_box.hide()
